======
otoole
======

.. image:: https://travis-ci.com/OSeMOSYS/otoole.svg?branch=master
    :target: https://travis-ci.com/OSeMOSYS/otoole

.. image:: https://coveralls.io/repos/github/OSeMOSYS/otoole/badge.svg?branch=master
    :target: https://coveralls.io/github/OSeMOSYS/otoole?branch=master

A Python toolkit to support use of OSeMOSYS


Description
===========

A longer description of your project goes here...


Note
====

This project has been set up using PyScaffold 3.2.2. For details and usage
information on PyScaffold see https://pyscaffold.org/.
